#!/usr/bin/bash

set -e -u

CRATE="async_zip"
NAME="rust-${CRATE}"

VERSION=$(rpmspec -q "$NAME.spec" --srpm --qf "%{version}")
URL="https://crates.io/api/v1/crates/${CRATE}/${VERSION}/download"

OUTDIR="${PWD}"
TMPDIR="$(mktemp -d)"
trap "rm -rf '${TMPDIR}'" INT TERM EXIT
ROOTDIR="${TMPDIR}/${CRATE}-${VERSION}"
mkdir "${ROOTDIR}"

# download and extract published crate from crates.io
CRATEFILE="${CRATE}-${VERSION}.crate"
wget "${URL}" -O "${TMPDIR}/${CRATEFILE}"
tar -C "${TMPDIR}" -xzf "${CRATEFILE}"
rm "${TMPDIR}/${CRATEFILE}"

pushd "${ROOTDIR}"

# remove SPECIFICATION.md, based on APPNOTE.TXT - .ZIP File Format
# Specification Version: 6.3.9, which is under a proprietary license from
# PKWARE: https://github.com/Majored/rs-async-zip/issues/146
rm SPECIFICATION.md

# clean up cargo files
rm .cargo_vcs_info.json
mv Cargo.toml.orig Cargo.toml

# repackage crate
cargo package

# move clean crate
mv "target/package/${CRATEFILE}" \
    "${OUTDIR}/$(basename "${CRATEFILE}" .crate)-clean.crate"

popd
